#!/bin/sh

prefix=/usr
exec_prefix=/usr
datarootdir=${prefix}/share

# perform a NTP update sync, before starting Enigma2, as it is broke in OE.
if [ -x /usr/sbin/ntpdate ]; then
	/usr/sbin/ntpdate -s -u pool.ntp.org && sleep 2
fi

# hook to execute user startup script before enigma2 start
if [ -x /etc/enigma2/startup.sh ]; then
	/etc/enigma2/startup.sh
fi

if [ -x /usr/bin/showiframe ]; then
	if [ -f /etc/enigma2/backdrop.mvi ]; then
		/usr/bin/showiframe /etc/enigma2/backdrop.mvi
	elif [ -f /etc/enigma2/bootlogo.mvi ]; then
		/usr/bin/showiframe /etc/enigma2/bootlogo.mvi
	elif [ -f /usr/share/bootlogo.mvi ]; then
		/usr/bin/showiframe /usr/share/bootlogo.mvi
	fi
fi

# hook to execute scripts always before enigma2 start
if [ -x /usr/bin/enigma2_pre_start.sh ]; then
	/usr/bin/enigma2_pre_start.sh
fi

if [ -d /home/root ]; then
	export HOME=/home/root
	cd
fi

#check for sundtek tuner helper lib
if [ -e /opt/lib/libmediaclient.so ]; then
	LIBS="/opt/lib/libmediaclient.so /usr/lib/libopen.so.0.0.0"
else
	LIBS="/usr/lib/libopen.so.0.0.0"
fi

sync

(sleep 2; echo "enigma2 is the main pvr application... adjust oom score!"; PID=$(pidof enigma2); \
	[ -e /proc/$PID/oom_score_adj ] && echo "-999" > /proc/$PID/oom_score_adj || echo "-17" > /proc/$PID/oom_adj;) &

if [ "$(grep config.crash.enabledebug /etc/enigma2/settings)" == "config.crash.enabledebug=True" ]; then
	if [ "$(grep config.crash.debug_path= /etc/enigma2/settings | sed 's/config.crash.debug_path=//g')" != "" -a -d "$(grep config.crash.debug_path= /etc/enigma2/settings | sed 's/config.crash.debug_path=//g')" ]; then
		LD_PRELOAD=$LIBS /usr/bin/enigma2 &> $(grep config.crash.debug_path= /etc/enigma2/settings | sed 's/config.crash.debug_path=//g')Enigma2_debug_$(date +%Y-%m-%d_%H-%M-%S).log
	else
		LD_PRELOAD=$LIBS /usr/bin/enigma2 &> /home/root/logs/Enigma2_debug_$(date +%Y-%m-%d_%H-%M-%S).log
	fi
else
	if [ ! "$(grep config.misc.firstrun=False /etc/enigma2/settings)" ]; then
		LD_PRELOAD=$LIBS /usr/bin/enigma2
	else
		LD_PRELOAD=$LIBS /usr/bin/enigma2 2> /dev/null
	fi
fi

# enigma2 exit codes:
#
# 1 - halt
# 2 - reboot
# 3 - restart enigma
#
# >128 signal

ret=$?
case $ret in
	1)
		/sbin/halt
		;;
	2)
		/sbin/reboot
		;;
	3)
		rm -f /tmp/.listen.camd.socket.ignore
		;;
	4)
		/sbin/rmmod lcd
		/usr/sbin/fpupgrade --upgrade 2>&1 | tee /home/root/fpupgrade.log
		sleep 1;
		/sbin/rmmod fp
		/sbin/modprobe fp
		/sbin/reboot
		;;
	5)
		if ! grep -q config.misc.RestartUI /etc/enigma2/settings; then
			echo "config.misc.RestartUI=true" >>/etc/enigma2/settings
		fi
		;;
	16)
		echo "rescue" > /proc/stb/fp/boot_mode
		/sbin/reboot
		;;
	42)
		# bind the console (when available)
		[ -f /sys/class/vtconsole/vtcon0/bind ] && echo 1 > /sys/class/vtconsole/vtcon0/bind
		( opkg upgrade sysvinit && opkg upgrade sysvinit-pidof && opkg upgrade initscripts-functions && opkg upgrade busybox && opkg upgrade kmod && opkg list-upgradable | cut -f 1 -d ' ' | xargs opkg upgrade ) 2>&1 | tee /home/root/ipkgupgrade.log
		/sbin/reboot
		;;
	43)
		#auto install and autobackup
		[ -f /sys/class/vtconsole/vtcon0/bind ] && echo 1 > /sys/class/vtconsole/vtcon0/bind
		/etc/init.d/settings-restore.sh
		/etc/init.d/avahi-daemon stop
		ifdown eth1
		ip addr flush dev eth1 scope global
		ifdown eth0
		ip addr flush dev eth0 scope global
		/etc/init.d/networking stop
		killall -9 udhcpc
		rm /var/run/udhcpc*
		/etc/init.d/dbus-1 reload
		/etc/init.d/networking start
		/etc/init.d/avahi-daemon start
		touch /etc/.doAutoinstall
		;;
	*)
		rm -f /tmp/.listen.camd.socket.ignore
		;;
esac
